==> haskell-crypton-conduit-0.2.3-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-Mw0LXh7MkJ6kQREPX99mJ
key:                  crypton-conduit-0.2.3-Mw0LXh7MkJ6kQREPX99mJ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  6ed6a2f63ca8b9ff0bc1d4ed30eb4753
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-Mw0LXh7MkJ6kQREPX99mJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-D4YiOfvDFG0FSohx4jmvQj
    conduit-extra-1.3.6-730UVkuRTVsDj6V9AWbsl9
    crypton-0.34-5oxuOJnBr8m3Lk3YkjhBKV exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-Emy1WDuYe6W3crmrzZuLqP transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-conduit-0.2.3-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-7xUMUoVYKIrIgRiqTeU2M5
key:                  crypton-conduit-0.2.3-7xUMUoVYKIrIgRiqTeU2M5
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  d559f5c54db8f43406d32f46e92c68c5
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-7xUMUoVYKIrIgRiqTeU2M5
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-I25roZFZ9rtE9pq7CzsSgq
    conduit-extra-1.3.6-7TbX0I2WNNG4Wr86Zc6tp0
    crypton-0.34-5oxuOJnBr8m3Lk3YkjhBKV exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-Emy1WDuYe6W3crmrzZuLqP transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
